# -*- coding: utf-8 -*-
# vim:fenc=utf-8

'''
  Backend workers powered by celery
  =================================

  :copyright (c) 2014 Xavier Bruhiere.
  :license: MIT, see LICENSE for more details.
'''

import os
from celery import Celery
import dna.time_utils


def setup(title, output='json', timezone=None):
    ''' Implement celery workers using json and redis '''
    timezone = timezone or dna.time_utils._detect_timezone()

    broker_url = 'redis://{}:{}/0'.format(
        os.environ.get('BROKER_HOST', 'localhost'),
        os.environ.get('BROKER_PORT', 6379)
    )

    app = Celery(title, backend=broker_url, broker=broker_url)

    app.conf.update(
        CELERY_TASK_SERIALIZER=output,
        CELERY_ACCEPT_CONTENT=[output],  # Ignore other content
        CELERY_RESULT_SERIALIZER=output,
        CELERY_TIMEZONE=timezone,
        CELERY_ENABLE_UTC=True,
    )

    return app
